#ifndef KERNELMESSAGESWINDOW_H
#define KERNELMESSAGESWINDOW_H

#include <QMainWindow>
#include <QFile>
#include <QString>
#include <QTextStream>
#include <QProcess>
#ifdef Q_WS_MAEMO_5
#include <QMaemo5InformationBox>
#include <QPalette>
#endif

namespace Ui {
    class KernelMessagesWindow;
}

class KernelMessagesWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit KernelMessagesWindow(QWidget *parent = 0);
    ~KernelMessagesWindow();
    Ui::KernelMessagesWindow *ui;
    QPalette *widget;
    QStringList *dmesgList;

public slots:
   // void showLogs();

private:
    QProcess *process;

private slots:
    void exportlogs();
};

#endif // KERNELMESSAGESWINDOW_H
